@@ -21,10 +21,19 @@ function(Z,X,Y=NULL,mode="mean"){
       }
     }
   }else{
-    for (ll in 1:length(Z)){
-      ind <- getsamples(Z[[ll]],X,levelvec=attr(Z,"levelvec"))
-      if(length(ind)>=1){
-        I[ind,ll] <- 1
+    if(mode=="member"){
+      for (ll in 1:length(Z)){
+        ind <- getsamples(Z[[ll]],X,levelvec=attr(Z,"levelvec"))
+        if(length(ind)>=1){
+          I[ind,ll] <- 1
+        }
+      }
+    }else{
+      for (ll in 1:length(Z)){
+        ind <- getsamples(Z[[ll]],X,levelvec=attr(Z,"levelvec"))
+        if(length(ind)>=1){
+          I[ind,ll] <- if(mode=="predict") attr(Z[[ll]],"predict") else attr(Z[[ll]],"mean")
+        }
       }
     }
   }
